import {Injectable} from '@angular/core';
import {HttpClient, HttpErrorResponse} from "@angular/common/http";
import {catchError} from 'rxjs/operators';
import {Observable, of} from 'rxjs';

interface IRequest {
  gql: string;
  variables?: any,
  success?: Function
  fail?: Function,
  showMessage?: boolean;
}

@Injectable({
  providedIn: 'root'
})
export class AppService {

  constructor(private http: HttpClient) {

  }

  // post方法
  post = ({gql, variables = {}, success, fail, showMessage = true}: IRequest) => {
    // this.loading = true;
    let options = {};
    // const token = this.storage.getToken();
    // const isLogin = this.storage.getIsLogin() === '1';
    // if (isLogin) {
    //   this.isLogin = isLogin;
    // }
    // if (token) {
    //   options = {
    //     ...options,
    //     headers: {
    //       'Authorization': token,
    //       'Platform': 'client'
    //     }
    //   };
    // }
    return this.http.post('/query', {
      query: gql,
      variables
    }, options).pipe(catchError(this.handleError)).subscribe((res: any) => {
      if (res) {
        const result = res.data;
        // this.loading = false;
        if (result) {
          success && success(result);
          return;
        }
        if (showMessage) {
          // this.message.remove();
          // this.message.warning(res.message || res.errors[0].message || '请求出错');
          // this.notification.remove();
          // this.notification.error('提示', res.message || '请求出错');
        }
        fail && fail(result);
      }
      // this.loading = false;
    });
  };

  // get方法
  get = ({url, success}:{url: string, success?:Function}) => {
    return this.http.get(url).pipe(catchError(this.handleError)).subscribe(res => {
      if (res) {
        const result = res.data;
        if (result) {
          success && success(result);
        }
      }
    });
  };

  handleError = (error: HttpErrorResponse) => {
    console.log('error：', error);
    if (error.status === 401) {
      const t = localStorage.getItem('s');
      // if (t) {
      //   // this.message.warning(error.error.message || '请求出错');
      //   this.message.warning('登陆过期，请重新登陆！');
      // }
      localStorage.clear();
      setTimeout(() => {
        location.href = '/index';
      }, 600)
      return of(null);
    }

    return of(error.error);
  };
}
