import {AfterContentInit, Component, OnInit} from '@angular/core';
import { Chart } from '@antv/g2';
import {AppService} from "../app.service";

@Component({
  selector: 'app-columnar',
  templateUrl: './columnar.component.html',
  styleUrls: ['./columnar.component.css']
})
export class ColumnarComponent implements OnInit, AfterContentInit {

  data = []

  constructor(public httpService: AppService) { }

  ngOnInit(): void {
  }

  ngAfterContentInit() {
    this.getData()
  }

  showColumnar() {
    const chart = new Chart({
      container: 'columnar',
      autoFit: true,
      height: 300,
      padding: [30,30,30,30]
    });

    chart.data(this.data);
    chart.scale('sales', {
      nice: true,
      alias: '笔',
    });
    chart.tooltip({
      showMarkers: false
    });
    chart.interaction('active-region')
    chart.interval().position('year*sales').size(28)
    // 添加文本标注
    this.data.forEach((item: any) => {
      chart.annotation()
        .text({
          position: [item.year, item.sales],
          content: item.sales,
          style: {
            textAlign: 'center',
            fill: '#FFFFFF',
          },
          offsetY: -10,
        })
    });
    chart.render();

  }

  getData() {
    this.httpService.get({
      url: 'https://www.taxbk.cn/qj/api/pc/achievement/areaLoanNum', success: (res: any) => {
        this.data = res.list.map((item: any) => ({
          year: item.name,
          sales: parseFloat(item.value)
        }))
        this.showColumnar()
      }
    })
  }
}
