import {AfterContentInit, Component, OnInit} from '@angular/core';
import { Chart } from '@antv/g2';
import {AppService} from "../app.service";

@Component({
  selector: 'app-financing',
  templateUrl: './financing.component.html',
  styleUrls: ['./financing.component.css']
})
export class FinancingComponent implements OnInit, AfterContentInit {

  data = [
    { type: '已授信', value: 40 },
    { type: '待处理', value: 21 },
    { type: '处理中', value: 17 },
    { type: '已拒绝', value: 13 }
  ];

  constructor(public httpService: AppService) { }

  ngOnInit(): void {
  }

  ngAfterContentInit() {
    this.getData()
  }

  showFinancing() {
    const chart = new Chart({
      container: 'financing',
      autoFit: true,
      height: 260,
    });
    chart.coordinate('theta', {
      radius: 0.75,
    });
    chart.data(this.data);
    chart.tooltip({
      showTitle: false,
      showMarkers: false,
    });
    chart
      .interval()
      .position('value')
      .color('type')
      .adjust('stack');
    chart.interaction('element-active');
    chart.render();
  }

  getData() {
    this.httpService.get({
      url: 'https://www.taxbk.cn/qj/api/pc/achievement/operate', success: (res: any) => {
        this.data[0].value = res.financingStatus.accepted
        this.data[1].value = res.financingStatus.pending
        this.data[2].value = res.financingStatus.accepting
        this.data[3].value = res.financingStatus.rejected
        this.showFinancing()
      }
    })
  }
}
