import {AfterContentInit, Component, OnInit} from '@angular/core';
import {Chart} from '@antv/g2';
import {AppService} from "../app.service";

@Component({
  selector: 'app-operate',
  templateUrl: './operate.component.html',
  styleUrls: ['./operate.component.css']
})
export class OperateComponent implements OnInit, AfterContentInit {
  title = 'app';
  data = [{
    type: '信用贷款',
    value: 83.6
  }, {
    type: '非纯信用贷款',
    value: 43.6
  }];
  chart: any;
  graph: any;
  registerTheme: any
  constructor(public httpService:AppService) {
  }

  ngOnInit(): void {
  }

  ngAfterContentInit() {
    this.getData()
  }

  chartData() {
    this.chart = new Chart({
      container: 'operate',
      autoFit: true,
      height: 300,
      theme: 'customTheme',
    });

    this.chart.data(this.data);
    this.chart.legend(false);
    this.chart.tooltip({
      showMarkers: false
    });
    this.chart.facet('rect', {
      fields: ['type'],
      padding: 20,
      showTitle: false,
      eachView: (view: any, facet: any) => {
        const data = facet.data;
        let color;
        if (data[0].type === '信用贷款') {
          color = '#0a9afe';
        } else {
          color = '#f0657d';
        }
        data.push({type: '其他', value: 100 - data[0].value});
        view.data(data);
        view.coordinate('theta', {
          radius: 0.8,
          innerRadius: 0.8
        });
        view
          .interval()
          .adjust('stack')
          .position('value')
          .color('type', [color, 'rgba(255,255,255,0.1)'])
          .style({
            opacity: 1,
          });
        view.annotation().text({
          position: ['50%', '50%'],
          content: data[0].type,
          style: {
            fontSize: 16,
            fill: '#FFFFFF',
            fontWeight: 200,
            textBaseline: 'bottom',
            textAlign: 'center'
          },
          offsetY: -12,
        });

        view.annotation().text({
          position: ['50%', '50%'],
          content: data[0].value + "%",
          style: {
            fontSize: 18,
            fill: '#FFFFFF',
            fontWeight: 200,
            textAlign: 'center'
          },
          offsetY: 10,
        });
        view.interaction('element-active');
      }
    });
    //  渲染图表
    this.chart.render();
  }

  getData() {
    this.httpService.get({
      url: 'https://www.taxbk.cn/qj/api/pc/achievement/operate', success: (res: any) => {
        this.data[0].value = parseFloat(res.proportion.creditProduct) * 100
        this.data[1].value = parseFloat(res.proportion.uncreditProduct) * 100
        this.chartData()
      }
    })
  }
}
